@@ -33,6 +33,10 @@
 #include "jsapi-private.h"
 
 #include <string.h>
+#include <math.h>
+#ifdef HAVE_MALLOC_H
+#include <malloc.h>
+#endif
 
 GQuark
 gjs_util_error_quark (void)
@@ -236,7 +240,7 @@ gjs_runtime_get_current_context(JSRuntime *runtime)
 
 static JSClass global_class = {
     "GjsGlobal", JSCLASS_GLOBAL_FLAGS,
-    JS_PropertyStub, JS_PropertyStub, JS_PropertyStub, JS_PropertyStub,
+    JS_PropertyStub, JS_PropertyStub, JS_PropertyStub, JS_StrictPropertyStub,
     JS_EnumerateStub, JS_ResolveStub, JS_ConvertStub, JS_FinalizeStub,
     JSCLASS_NO_OPTIONAL_MEMBERS
 };
@@ -255,7 +259,11 @@ gjs_init_context_standard (JSContext       *context)
 {
     JSObject *global;
 #ifdef HAVE_MOZJS_2
+#ifdef HAVE_JS_NEWCOMPARTMENTANDGLOBALOBJECT
+    global = JS_NewCompartmentAndGlobalObject(context, &global_class, NULL);
+#else
     global = JS_NewGlobalObject(context, &global_class);
+#endif /* HAVE_JS_NEWCOMPARTMENTANDGLOBALOBJECT */
     if (global == NULL)
         return FALSE;
 #else
@@ -263,7 +271,7 @@ gjs_init_context_standard (JSContext       *context)
     if (global == NULL)
         return FALSE;
     JS_SetGlobalObject(context, global);
-#endif
+#endif /* HAVE_MOZJS_2 */
     if (!JS_InitStandardClasses(context, global))
         return FALSE;
     return TRUE;
@@ -807,6 +815,8 @@ gjs_value_debug_string(JSContext      *context,
         bytes = g_malloc((len + 1) * sizeof(char));
         JS_EncodeStringToBuffer(str, bytes, len);
         bytes[len] = '\0';
+    } else {
+        bytes = g_strdup("[invalid string]");
     }
 #endif
     JS_EndRequest(context);
@@ -904,7 +914,7 @@ gjs_explain_scope(JSContext  *context,
               global, debugstr);
     g_free(debugstr);
 
-    parent = JS_GetScopeChain(context);
+    parent = JS_GetGlobalForScopeChain(context);
     chain = g_string_new(NULL);
     while (parent != NULL) {
         char *debug;
@@ -1512,3 +1522,41 @@ gjs_parse_args (JSContext  *context,
     JS_EndRequest(context);
     return JS_FALSE;
 }
+
+/**
+ * gjs_maybe_gc:
+ *
+ * Low level version of gjs_context_maybe_gc().
+ */
+void
+gjs_maybe_gc (JSContext *context)
+{
+    /* Picked this number out of the air basically; 16 megabytes
+     * "feels" good for all of mobile/embedded/GP.  We don't
+     * expect the cost of JS_GC() to be too high, but we
+     * also don't want to call it too often.
+     *
+     * A better approach actually may be to dynamically watch "free";
+     * how much memory we're using before we hit swap.  Even better of
+     * course: some component of the OS sends us a signal when we
+     * should be trying a GC.
+     */
+#define _GJS_MAYBE_GC_MALLOC_BYTES (16 * 1024 * 1024)
+
+    static int _gjs_last_maybe_gc_malloc_blocks = -1;
+    
+    JS_MaybeGC(context);
+
+#ifdef HAVE_MALLINFO
+    {
+        struct mallinfo mstats;
+        mstats = mallinfo();
+        if (mstats.uordblks < _gjs_last_maybe_gc_malloc_blocks || _gjs_last_maybe_gc_malloc_blocks == -1) {
+            _gjs_last_maybe_gc_malloc_blocks = mstats.uordblks;
+        } else if ((mstats.uordblks - _gjs_last_maybe_gc_malloc_blocks) > _GJS_MAYBE_GC_MALLOC_BYTES) {
+            JS_GC(context);
+            _gjs_last_maybe_gc_malloc_blocks = mstats.uordblks;
+        }
+    }     
+#endif    
+}
