@@ -1,3 +1,4 @@
+// application/javascript;version=1.8
 // This used to be called "Everything"
 const Everything = imports.gi.Regress;
 if (!('assertEquals' in this)) { /* allow running this test standalone */
@@ -74,6 +75,10 @@ function testLifeUniverseAndEverything() {
     assertEquals(42, Everything.test_double(42));
     assertEquals(-42, Everything.test_double(-42));
 
+    assertEquals("c", Everything.test_unichar("c"));
+    assertEquals("", Everything.test_unichar(""));
+    assertEquals("\u2665", Everything.test_unichar("\u2665"));
+
     let now = Math.floor(new Date().getTime() / 1000);
     let bounced = Math.floor(Everything.test_timet(now));
     assertEquals(bounced, now);
@@ -152,7 +157,6 @@ function testUtf8() {
 
     assertEquals(CONST_STR, Everything.test_utf8_const_return());
     assertEquals(NONCONST_STR, Everything.test_utf8_nonconst_return());
-    Everything.test_utf8_nonconst_in(NONCONST_STR);
     Everything.test_utf8_const_in(CONST_STR);
     assertEquals(NONCONST_STR, Everything.test_utf8_out());
     assertEquals(NONCONST_STR, Everything.test_utf8_inout(CONST_STR));
@@ -258,7 +262,6 @@ function testGListIn() {
     Everything.test_glist_nothing_in(STR_LIST);
     Everything.test_glist_nothing_in2(STR_LIST);
     //Everything.test_glist_container_in(STR_LIST);
-    Everything.test_glist_everything_in(STR_LIST);
 }
 
 /* GSList types */
@@ -273,7 +276,6 @@ function testGSListIn() {
     Everything.test_gslist_nothing_in(STR_LIST);
     Everything.test_gslist_nothing_in2(STR_LIST);
     //Everything.test_gslist_container_in(STR_LIST);
-    Everything.test_gslist_everything_in(STR_LIST);
 }
 
 /* Array tests */
@@ -328,8 +330,6 @@ function testGHashIn() {
     Everything.test_ghash_null_in(null);
     Everything.test_ghash_nothing_in(STR_HASH);
     Everything.test_ghash_nothing_in2(STR_HASH);
-    //Everything.test_ghash_container_in(STR_HASH);
-    Everything.test_ghash_everything_in(STR_HASH);
 }
 
 function testNestedGHashOut() {
@@ -340,8 +340,17 @@ function testNestedGHashOut() {
 
 /* Enums */
 function testEnumParam() {
-   let e = Everything.test_enum_param(Everything.TestEnum.VALUE1);
+   let e;
+
+   e = Everything.test_enum_param(Everything.TestEnum.VALUE1);
    assertEquals('Enum parameter', 'value1', e);
+   e = Everything.test_enum_param(Everything.TestEnum.VALUE3);
+   assertEquals('Enum parameter', 'value3', e);
+
+   e = Everything.test_unsigned_enum_param(Everything.TestEnumUnsigned.VALUE1);
+   assertEquals('Enum parameter', 'value1', e);
+   e = Everything.test_unsigned_enum_param(Everything.TestEnumUnsigned.VALUE2);
+   assertEquals('Enum parameter', 'value2', e);
 }
 
 function testSignal() {
